@@ -10,6 +10,9 @@ setMethod(".set_labels", signature(x="familiarCollection"),
             # Suppress NOTES due to non-standard evaluation in data.table
             label <- NULL
             
+            # Make sure the collection object is updated.
+            x <- update_object(object=x)
+            
             # Read the slot
             label_table <- slot(x, upd_slot)
             
@@ -178,6 +181,9 @@ setMethod(".get_labels", signature(x="familiarCollection"),
             # Suppress NOTES due to non-standard evaluation in data.table
             label_order <- NULL
             
+            # Make sure the collection object is updated.
+            x <- update_object(object=x)
+            
             # Determine if the slot has been set.
             if(is.null(slot(x, upd_slot))){
               x <- .construct_label_table(x=x, upd_slot=upd_slot)
@@ -532,8 +538,11 @@ setMethod("get_object_name", signature(object="familiarCollection"),
 setMethod("show", signature(object="familiarCollection"),
           function(object){
             
+            # Make sure the collection object is updated.
+            object <- update_object(object=object)
+            
             # Create an initial descriptor.
-            cat(paste0("A collection of datasets (", object@name, "; v", object@familiar_version, "):\n"))
+            cat(paste0("A collection of datasets (", object@name, "; ", .familiar_version_string(object), "):\n"))
             lapply(object@data_sets, function(x) cat(paste0("  ", x, "\n")))
             
             # Outcome details
