@@ -596,7 +596,7 @@ setMethod("plot_ice", signature(object="familiarCollection"),
             ##### Check input arguments ------------------------------------------------
             
             # ggtheme
-            if(!inherits(ggtheme, "theme")) ggtheme <- plotting.get_theme(use_theme=ggtheme)
+            ggtheme <- .check_ggtheme(ggtheme)
 
             # Determine whether 1D or 2D plots are shown.
             show_2d <- any(sapply(ice_data, function(x) (!is.null(x@identifiers$feature_y))))
@@ -1355,7 +1355,7 @@ setMethod("plot_ice", signature(object="familiarCollection"),
   
   
   # Make pd line thicker than ice lines.
-  ice_line_size <- 0.5 * ggtheme$line$size
+  ice_line_size <- 0.5 * ..get_plot_theme_linewidth(ggtheme=ggtheme)
   pd_line_size <- 6 * ice_line_size
   
   # In case only partial dependency plots are shown, update ice_default_alpha
@@ -1374,48 +1374,116 @@ setMethod("plot_ice", signature(object="familiarCollection"),
     p <- p + ggplot2::geom_blank()
     
   } else if(show_novelty){
-    # With novelty.
+    # Plot with novelty.
     
-    if(show_ice){
-      if(!is.null(color_by)){
-        # Create lines with alpha.
-        p <- p + ggplot2::geom_line(data=ice_guide_list$data,
-                                    mapping=ggplot2::aes(x=!!sym("feature_x_value"),
-                                                         y=!!sym("value"),
-                                                         alpha=!!sym("novelty"),
-                                                         colour=!!sym("color_breaks"),
-                                                         group=!!sym("color_breaks_sample")),
-                                    size=ice_line_size)
-        
-      } else {
-        # Create lines with alpha.
-        p <- p + ggplot2::geom_line(data=ice_guide_list$data,
-                                    mapping=ggplot2::aes(x=!!sym("feature_x_value"),
-                                                         y=!!sym("value"),
-                                                         group=!!sym("sample"),
-                                                         alpha=!!sym("novelty")),
-                                    size=ice_line_size)
+    if(utils::packageVersion("ggplot2") >= "3.4.0"){
+      # Version 3.4.0 introduces the linewidth element for geom_line, and will
+      # produce deprecation warnings if the size argument is used instead.
+      
+      if(show_ice){
+        if(!is.null(color_by)){
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=ice_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              alpha=!!sym("novelty"),
+              colour=!!sym("color_breaks"),
+              group=!!sym("color_breaks_sample")),
+            linewidth=ice_line_size)
+          
+        } else {
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=ice_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              group=!!sym("sample"),
+              alpha=!!sym("novelty")),
+            linewidth=ice_line_size)
+        }
       }
-    }
-    
-    if(show_pd){
-      if(!is.null(color_by)){
-        # Create lines with alpha.
-        p <- p + ggplot2::geom_line(data=pd_guide_list$data,
-                                    mapping=ggplot2::aes(x=!!sym("feature_x_value"),
-                                                         y=!!sym("value"),
-                                                         alpha=!!sym("novelty"),
-                                                         colour=!!sym("color_breaks"),
-                                                         group=pd_group_variable),
-                                    size=pd_line_size)
-      } else {
-        # Create lines with alpha.
-        p <- p + ggplot2::geom_line(data=pd_guide_list$data,
-                                    mapping=ggplot2::aes(x=!!sym("feature_x_value"),
-                                                         y=!!sym("value"),
-                                                         alpha=!!sym("novelty"),
-                                                         group=pd_group_variable),
-                                    size=pd_line_size)
+      
+      if(show_pd){
+        if(!is.null(color_by)){
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=pd_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              alpha=!!sym("novelty"),
+              colour=!!sym("color_breaks"),
+              group=pd_group_variable),
+            linewidth=pd_line_size)
+          
+        } else {
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=pd_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              alpha=!!sym("novelty"),
+              group=pd_group_variable),
+            linewidth=pd_line_size)
+        }
+      }
+    } else {
+      # For backward compatibility with versions of ggplot2 before version
+      # 3.4.0.
+      if(show_ice){
+        if(!is.null(color_by)){
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=ice_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              alpha=!!sym("novelty"),
+              colour=!!sym("color_breaks"),
+              group=!!sym("color_breaks_sample")),
+            size=ice_line_size)
+          
+        } else {
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=ice_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              group=!!sym("sample"),
+              alpha=!!sym("novelty")),
+            size=ice_line_size)
+        }
+      }
+      
+      if(show_pd){
+        if(!is.null(color_by)){
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=pd_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              alpha=!!sym("novelty"),
+              colour=!!sym("color_breaks"),
+              group=pd_group_variable),
+            size=pd_line_size)
+          
+        } else {
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=pd_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              alpha=!!sym("novelty"),
+              group=pd_group_variable),
+            size=pd_line_size)
+        }
       }
     }
     
@@ -1425,47 +1493,112 @@ setMethod("plot_ice", signature(object="familiarCollection"),
                                   range=c(0.1, 1.0) * ice_default_alpha)
     
   } else {
-    # Without novelty
+    # Plot without novelty.
     
-    if(show_ice){
-      if(!is.null(color_by)){
-        # Create lines with alpha.
-        p <- p + ggplot2::geom_line(data=ice_guide_list$data,
-                                    mapping=ggplot2::aes(x=!!sym("feature_x_value"),
-                                                         y=!!sym("value"),
-                                                         group=!!sym("color_breaks_sample"),
-                                                         colour=!!sym("color_breaks")),
-                                    size=ice_line_size,
-                                    alpha=ice_default_alpha)
-        
-      } else {
-        # Create lines with alpha.
-        p <- p + ggplot2::geom_line(data=ice_guide_list$data,
-                                    mapping=ggplot2::aes(x=!!sym("feature_x_value"),
-                                                         y=!!sym("value"),
-                                                         group=!!sym("sample")),
-                                    size=ice_line_size,
-                                    alpha=ice_default_alpha)
+    if(utils::packageVersion("ggplot2") >= "3.4.0"){
+      # Version 3.4.0 introduces the linewidth element for geom_line, and will
+      # produce deprecation warnings if the size argument is used instead.
+      if(show_ice){
+        if(!is.null(color_by)){
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=ice_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              group=!!sym("color_breaks_sample"),
+              colour=!!sym("color_breaks")),
+            linewidth=ice_line_size,
+            alpha=ice_default_alpha)
+          
+        } else {
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=ice_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              group=!!sym("sample")),
+            linewidth=ice_line_size,
+            alpha=ice_default_alpha)
+        }
       }
-    }
-    
-    if(show_pd){
-      if(!is.null(color_by)){
-        # Create lines with alpha.
-        p <- p + ggplot2::geom_line(data=pd_guide_list$data,
-                                    mapping=ggplot2::aes(x=!!sym("feature_x_value"),
-                                                         y=!!sym("value"),
-                                                         colour=!!sym("color_breaks"),
-                                                         group=pd_group_variable),
-                                    size=pd_line_size)
-        
-      } else {
-        # Create lines with alpha.
-        p <- p + ggplot2::geom_line(data=pd_guide_list$data,
-                                    mapping=ggplot2::aes(x=!!sym("feature_x_value"),
-                                                         y=!!sym("value"),
-                                                         group=pd_group_variable),
-                                    size=pd_line_size)
+      
+      if(show_pd){
+        if(!is.null(color_by)){
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=pd_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              colour=!!sym("color_breaks"),
+              group=pd_group_variable),
+            linewidth=pd_line_size)
+          
+        } else {
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=pd_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              group=pd_group_variable),
+            linewidth=pd_line_size)
+        }
+      }
+      
+    } else {
+      # For backwards compatibility with ggplot2 versions prior to version
+      # 3.4.0.
+      if(show_ice){
+        if(!is.null(color_by)){
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=ice_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              group=!!sym("color_breaks_sample"),
+              colour=!!sym("color_breaks")),
+            size=ice_line_size,
+            alpha=ice_default_alpha)
+          
+        } else {
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=ice_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              group=!!sym("sample")),
+            size=ice_line_size,
+            alpha=ice_default_alpha)
+        }
+      }
+      
+      if(show_pd){
+        if(!is.null(color_by)){
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=pd_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              colour=!!sym("color_breaks"),
+              group=pd_group_variable),
+            size=pd_line_size)
+          
+        } else {
+          # Create lines with alpha.
+          p <- p + ggplot2::geom_line(
+            data=pd_guide_list$data,
+            mapping=ggplot2::aes(
+              x=!!sym("feature_x_value"),
+              y=!!sym("value"),
+              group=pd_group_variable),
+            size=pd_line_size)
+        }
       }
     }
   }
@@ -1479,10 +1612,11 @@ setMethod("plot_ice", signature(object="familiarCollection"),
       g_color <- pd_guide_list$guide_color
     }
     
-    p <- p + ggplot2::scale_colour_manual(name=legend_label$guide_color,
-                                          values=g_color$color_values,
-                                          breaks=g_color$color_breaks,
-                                          drop=FALSE)
+    p <- p + ggplot2::scale_colour_manual(
+      name=legend_label$guide_color,
+      values=g_color$color_values,
+      breaks=g_color$color_breaks,
+      drop=FALSE)
   }
   
   # Update x and y scales
