@@ -398,10 +398,10 @@ setMethod("plot_sample_clustering", signature(object="familiarCollection"),
             ##### Check input arguments ----------------------------------------
             
             # ggtheme
-            if(!is(ggtheme, "theme")) {
-              ggtheme <- plotting.get_theme(use_theme=ggtheme)
-              
-            } else if(is.waive(rotate_x_tick_labels)){
+            ggtheme <- .check_ggtheme(ggtheme)
+            
+            # rotate_x_tick_labels
+            if(is.waive(rotate_x_tick_labels)){
               rotate_x_tick_labels <- FALSE
             }
             
