@@ -230,6 +230,58 @@ test.create_good_data_few_censored_set <- function(outcome_type){
 
 
 
+test_create_good_data_set_random_na_data <- function(outcome_type,
+                                                     n_missing_frac=0.05,
+                                                     seed=1844,
+                                                     rstream_object=NULL){
+  # Some data points are NA, but not instances.
+  if(!is.null(seed) & is.null(rstream_object)){
+    rstream_object <- .start_random_number_stream(seed=seed)
+  }
+  
+  # Create test data.
+  data <- test.create_good_data_set(outcome_type=outcome_type)
+  
+  # Get the number of rows and feature columns.
+  n_rows <- nrow(data@data)
+  feature_columns <- get_feature_columns(data)
+  
+  # Select the number of data points to randomise.
+  n_randomise <- ceiling(n_missing_frac * n_rows * length(feature_columns))
+  
+  # Determine which data points should be randomised.
+  random_data <- data.table::data.table("row_id"=fam_sample(seq_len(n_rows),
+                                                            size=n_randomise,
+                                                            replace=TRUE,
+                                                            rstream_object=rstream_object),
+                                        "feature"=fam_sample(feature_columns,
+                                                             size=n_randomise,
+                                                             replace=TRUE,
+                                                             rstream_object=rstream_object))
+  # Select only unique data points.
+  random_data <- unique(random_data)
+  
+  # Split for iteration.
+  random_data <- split(random_data, by="feature", drop=TRUE)
+  
+  # Update feature columns.
+  for(feature in feature_columns){
+    if(!is.null(random_data[[feature]])){
+      
+      # Split by numeric and factor features.
+      if(is.factor(data@data[[feature]])){
+        data@data[random_data[[feature]]$row_id, (feature):=NA]
+        
+      } else {
+        data@data[random_data[[feature]]$row_id, (feature):=NA_real_]
+      }
+    }
+  }
+  
+  return(data)
+}
+
+
 test.create_empty_data_set <- function(outcome_type){
   
   # Create good dataset first and work from there.
@@ -243,10 +295,23 @@ test.create_empty_data_set <- function(outcome_type){
 
 
 
+test.create_no_feature_data_set <- function(outcome_type){
+  
+  # Create good dataset first and work from there.
+  data <- test.create_good_data_set(outcome_type)
+  
+  # Remove features.
+  data@data <- data@data[, mget(get_non_feature_columns(outcome_type))]
+  
+  return(data)
+}
+
+
+
 test.create_bootstrapped_data_set <- function(outcome_type, to_data_object=TRUE){
   
   # Suppress NOTES due to non-standard evaluation in data.table
-  .NATURAL <- sample_id <- NULL
+  sample_id <- NULL
   
   # Create good dataset first and work from there.
   data <- test.create_good_data_set(outcome_type=outcome_type,
@@ -254,14 +319,19 @@ test.create_bootstrapped_data_set <- function(outcome_type, to_data_object=TRUE)
   
   # Now keep only the first sample.
   if(to_data_object){
-    data@data[fam_sample(data@data, replace=TRUE), on=.NATURAL][order(sample_id)]
+    data@data <- data@data[fam_sample(seq_len(nrow(data@data)),
+                                      size=nrow(data@data),
+                                      replace=TRUE,
+                                      seed=1844)][order(sample_id)]
     
   } else {
-    data[fam_sample(data, replace=TRUE), on=.NATURAL][order(sample_id)]
+    data@data <- data[fam_sample(seq_len(nrow(data)),
+                                 size=nrow(data),
+                                 replace=TRUE,
+                                 seed=1844)][order(sample_id)]
   }
   
   return(data)
-  
 }
 
 
@@ -1062,6 +1132,7 @@ test_create_synthetic_series_na_data <- function(outcome_type,
                                                  n_missing_frac=0.1,
                                                  seed=1844,
                                                  rstream_object=NULL){
+  # Some instances are completely NA.
   
   # Create test data.
   data <- test_create_synthetic_series_data(outcome_type=outcome_type,
@@ -1095,6 +1166,64 @@ test_create_synthetic_series_na_data <- function(outcome_type,
 
 
 
+test_create_synthetic_series_random_na_data <- function(outcome_type,
+                                                        n_numeric=4L,
+                                                        n_missing_frac=0.1,
+                                                        seed=1844,
+                                                        rstream_object=NULL){
+  # Some data points are NA, but not instances.
+  
+  
+  if(!is.null(seed) & is.null(rstream_object)){
+    rstream_object <- .start_random_number_stream(seed=seed)
+  }
+  
+  # Create test data.
+  data <- test_create_synthetic_series_data(outcome_type=outcome_type,
+                                            n_numeric=n_numeric,
+                                            rstream_object=rstream_object)
+  
+  # Get the number of rows and feature columns.
+  n_rows <- nrow(data@data)
+  feature_columns <- get_feature_columns(data)
+  
+  # Select the number of data points to randomise.
+  n_randomise <- ceiling(n_missing_frac * n_rows * length(feature_columns))
+  
+  # Determine which data points should be randomised.
+  random_data <- data.table::data.table("row_id"=fam_sample(seq_len(n_rows),
+                                                            size=n_randomise,
+                                                            replace=TRUE,
+                                                            rstream_object=rstream_object),
+                                        "feature"=fam_sample(feature_columns,
+                                                             size=n_randomise,
+                                                             replace=TRUE,
+                                                             rstream_object=rstream_object))
+  # Select only unique data points.
+  random_data <- unique(random_data)
+  
+  # Split for iteration.
+  random_data <- split(random_data, by="feature", drop=TRUE)
+  
+  # Update feature columns.
+  for(feature in feature_columns){
+    if(!is.null(random_data[[feature]])){
+      
+      # Split by numeric and factor features.
+      if(is.factor(data@data[[feature]])){
+        data@data[random_data[[feature]]$row_id, (feature):=NA]
+        
+      } else {
+        data@data[random_data[[feature]]$row_id, (feature):=NA_real_]
+      }
+    }
+  }
+  
+  return(data)
+}
+
+
+
 test_create_synthetic_series_one_feature_all_na_data <- function(outcome_type,
                                                                  n_numeric=4L,
                                                                  seed=1844,
@@ -1120,6 +1249,7 @@ test_create_synthetic_series_one_feature_all_na_data <- function(outcome_type,
 }
 
 
+
 test_create_multiple_synthetic_series <- function(outcome_type){
   # The idea here is to create multiple synthetic datasets that together
   # represent extreme variation in data composition.
@@ -1182,3 +1312,183 @@ test_create_multiple_synthetic_series <- function(outcome_type){
               "set_3"=data_3,
               "set_4"=data_4))
 }
+
+
+
+
+test_create_synthetic_correlated_data <- function(...,
+                                                  seed=1844,
+                                                  rstream_object=NULL,
+                                                  cluster_size=c(1, 1, 1, 1),
+                                                  mix_feature_types=TRUE,
+                                                  allow_anti_correlation=TRUE){
+  
+  # Create random stream object so that the same numbers are produced every
+  # time.
+  if(is.null(rstream_object)){
+    r <- .start_random_number_stream(seed=seed)
+    
+  } else {
+    r <- rstream_object
+  }
+  
+  # Create basic data.
+  base_data <- do.call(test_create_synthetic_series_data,
+                       args=c(list("rstream_object"=r),
+                              list(...)))
+  
+  if(length(cluster_size) != get_n_features(base_data)){
+    stop(paste0("The cluster_size argument should match the number of features."))
+  }
+  
+  # Get feature names prior to extending the dataset.
+  original_feature_names <- get_feature_columns(base_data)
+  
+  # Create copy of data.
+  data <- base_data
+  data@data <- data.table::copy(base_data@data)
+  
+  for(ii in seq_along(cluster_size)){
+    
+    # Skip if no clusters are required.
+    if(cluster_size[ii] == 1) next()
+    
+    # Isolate feature data. Force reading this data just in case.
+    x <- base_data@data[[original_feature_names[ii]]]
+
+    # Generate clusters.
+    for(jj in seq_len(cluster_size[ii])){
+      # Create the name of the new feature.
+      new_feature_name <- paste0(original_feature_names[ii], "_", LETTERS[jj])
+      
+      if(jj == 1){
+        # The first feature should just be renamed.
+        data.table::setnames(data@data,
+                             old=original_feature_names[ii],
+                             new=new_feature_name)
+        
+      } else if(jj == 2 & is.factor(x) & mix_feature_types){
+        # Add numeric feature when mixing data types.
+        data@data[, (new_feature_name):=as.numeric(x) * 1.1]
+        
+      } else if(is.factor(x)){
+        # For categorical features, remix the levels.
+        y <- factor(x,
+                    levels=levels(x),
+                    labels=levels(x)[fam_sample(seq_along(levels(x)),
+                                                size=length(levels(x)),
+                                                replace=FALSE,
+                                                rstream_object=r)])
+        # Set feature.
+        data@data[, (new_feature_name):=y]
+        
+      } else {
+        # For numerical features, introduce an offset and scaling. We scale
+        # between 0.5 and 1.5 or -0.5 and -1.5 to avoid multiplying by 0. The negative values are used for strong anti-correlation, which 
+        if(jj %% 2 == 0 | !allow_anti_correlation){
+          r_scale <- fam_runif(n=1L, min=0.5, max=1.5, rstream_object=r)
+          
+        } else {
+          r_scale <- fam_runif(n=1L, min=-1.5, max=-0.5, rstream_object=r)
+        }
+        
+        r_shift <- fam_runif(n=1L, min=-1.0, max=1.0, rstream_object=r)
+        
+        y <- x * r_scale + r_shift
+        
+        data@data[, (new_feature_name):=y]
+      }
+    }
+  }
+  
+  # Order columns nicely.
+  data.table::setcolorder(data@data, c(get_non_feature_columns(data),
+                                       sort(get_feature_columns(data))))
+  
+  return(data)
+}
+
+
+
+test_create_synthetic_correlated_one_feature_invariant_data <- function(...,
+                                                                        cluster_size=c(1, 1, 1, 1)){
+  
+  # Set the size of the second cluster to 1, always.
+  cluster_size[2] <- 1
+  
+  # Create test data.
+  data <- do.call(test_create_synthetic_correlated_data,
+                  args=c(list("cluster_size"=cluster_size),
+                         list(...)))
+  
+  # Select the first instance for feature 2.
+  data@data$feature_2 <- data@data$feature_2[1]
+  
+  return(data)
+}
+
+
+
+test_create_synthetic_correlated_one_sample_data <- function(...){
+  
+  # Create test data.
+  data <- do.call(test_create_synthetic_correlated_data,
+                  args=list(...))
+  
+  # Select the first instance
+  data@data <- head(data@data, n=1L)
+  
+  return(data)
+}
+
+
+
+test_create_synthetic_correlated_one_outcome_data <- function(...,
+                                                              outcome_type){
+  
+  # Create test data.
+  data <- do.call(test_create_synthetic_correlated_data,
+                  args=c(list("outcome_type"=outcome_type),
+                         list(...)))
+  
+  if(outcome_type %in% c("binomial", "multinomial")){
+    data@data[, "outcome":="0"]
+    
+  } else if(outcome_type %in% c("count", "continuous")){
+    data@data[, "outcome":=1]
+    
+  } else if(outcome_type == "survival"){
+    data@data[, ":="("outcome_time"=1.25, "outcome_event"=1)]
+    
+  } else {
+    ..error_outcome_type_not_implemented(outcome_type)
+  }
+  
+  return(data)
+}
+
+
+
+test_create_synthetic_correlated_bad_outcome_data <- function(...,
+                                                              outcome_type){
+  
+  # Create test data.
+  data <- do.call(test_create_synthetic_correlated_data,
+                  args=c(list("outcome_type"=outcome_type),
+                         list(...)))
+  
+  if(outcome_type %in% c("binomial", "multinomial")){
+    data@data[, "outcome":="0"]
+    
+  } else if(outcome_type %in% c("count", "continuous")){
+    data@data[, "outcome":=1]
+    
+  } else if(outcome_type == "survival"){
+    data@data[, ":="("outcome_event"=0)]
+    
+  } else {
+    ..error_outcome_type_not_implemented(outcome_type)
+  }
+  
+  return(data)
+}
