@@ -3,11 +3,6 @@ testthat::skip_on_cran()
 
 debug_flag <- FALSE
 
-familiar:::test_plots(plot_function=familiar:::plot_ice,
-                      not_available_some_predictions_fail=FALSE,
-                      data_element="ice_data",
-                      debug=debug_flag)
-
 # Test alignment of different plots, with missing data.
 familiar:::test_plot_ordering(plot_function=familiar:::plot_ice,
                               data_element="ice_data",
